@@ -11,15 +11,15 @@
 #define SO_PEERSEC 31
 #endif
 
-int getpeercon_raw(int fd, security_context_t *context)
+int getpeercon_raw(int fd, char ** context)
 {
 	char *buf;
 	socklen_t size;
 	ssize_t ret;
 
-	size = INITCONTEXTLEN+1;
+	size = INITCONTEXTLEN + 1;
 	buf = malloc(size);
-	if (!buf) 
+	if (!buf)
 		return -1;
 	memset(buf, 0, size);
 
@@ -35,30 +35,27 @@ int getpeercon_raw(int fd, security_context_t *context)
 		memset(buf, 0, size);
 		ret = getsockopt(fd, SOL_SOCKET, SO_PEERSEC, buf, &size);
 	}
-out:			
+      out:
 	if (ret < 0)
 		free(buf);
 	else
 		*context = buf;
 	return ret;
 }
+
 hidden_def(getpeercon_raw)
 
-int getpeercon(int fd, security_context_t *context)
+int getpeercon(int fd, char ** context)
 {
 	int ret;
-	security_context_t rcontext;
+	char * rcontext;
 
- 	ret = getpeercon_raw(fd, &rcontext);
+	ret = getpeercon_raw(fd, &rcontext);
 
-	if (context_translations && !ret) {
-		if (raw_to_trans_context(rcontext, context)) {
-			*context = NULL;
-			ret = -1;
-		}
+	if (!ret) {
+		ret = selinux_raw_to_trans_context(rcontext, context);
 		freecon(rcontext);
-	} else if (!ret)
-		*context = rcontext;
+	}
 
 	return ret;
 }
