@@ -15,8 +15,13 @@ int security_setenforce(int value)
 	char path[PATH_MAX];
 	char buf[20];
 
+	if (!selinux_mnt) {
+		errno = ENOENT;
+		return -1;
+	}
+
 	snprintf(path, sizeof path, "%s/enforce", selinux_mnt);
-	fd = open(path, O_RDWR);
+	fd = open(path, O_RDWR | O_CLOEXEC);
 	if (fd < 0)
 		return -1;
 
@@ -28,4 +33,5 @@ int security_setenforce(int value)
 
 	return 0;
 }
+
 hidden_def(security_setenforce)
