@@ -3,7 +3,7 @@
 #include <stdlib.h>
 #include <selinux/selinux.h>
 
-int main(int argc, char **argv) 
+int main(int argc, char **argv)
 {
 	char *buf;
 	int rc, i;
@@ -16,7 +16,8 @@ int main(int argc, char **argv)
 	for (i = 1; i < argc; i++) {
 		rc = getfilecon(argv[i], &buf);
 		if (rc < 0) {
-			fprintf(stderr, "%s:  getfilecon(%s) failed\n", argv[0], argv[i]);
+			fprintf(stderr, "%s:  getfilecon(%s) failed\n", argv[0],
+				argv[i]);
 			exit(2);
 		}
 		printf("%s\t%s\n", argv[i], buf);
